@@ -15,7 +15,7 @@ Perl::Examples::POD::Link - Show the various examples of links
 
 =head1 VERSION
 
-This document describes version 0.05 of Perl::Examples::POD::Link (from Perl distribution Perl-Examples), released on 2016-02-08.
+This document describes version 0.06 of Perl::Examples::POD::Link (from Perl distribution Perl-Examples), released on 2016-03-21.
 
 =head1 DESCRIPTION
 
@@ -31,7 +31,7 @@ Link to module with text: L<The Perl-Examples main module|Perl::Examples>
 
 Link to module with text + section: L<The description of Perl-Examples main module|Perl::Examples/"DESCRIPTION">
 
-Link this page with text + section: L<A collection of URL links/"URL links">
+Link this page with text + section: L<A collection of URL links|/"URL links">
 
 Link to script: L<perl-example-die>
 
